$hidePDF = $false
$workingDirectory = "C:\Temp\$($file._Name)"
$localPDFfileLocation = "$workingDirectory\$($file._Name).pdf"
$vaultPDFfileLocation = $file._EntityPath +"/"+ (Split-Path -Leaf $localPDFfileLocation)

Write-Host "Starting job 'Create 3D-PDF as attachment' for file '$($file._Name)' ..."

if( @("ipt","iam") -notcontains $file._Extension ) {
    Write-Host "Files with extension: '$($file._Extension)' are not supported"
    return
}

$downloadedFiles = Save-VaultFile -File $file._FullPath -DownloadDirectory $workingDirectory
$file = $downloadedFiles | select -First 1
$openResult = Open-Document -LocalFile $file.LocalPath

if($openResult) {
    $Application = $openResult.Application.Instance
    $Document = $openResult.Document.Instance
    try {
	    $exportResult = Export-3DPdf -Application $Application -Document $Document -PdfFullPath $localPDFfileLocation -Accuracy:kHigh
    } catch {
        throw("Failed to export document $($file.LocalPath) to $localPDFfileLocation! Reason: $($Error[0])")
    } finally {
        Close-Document
        Clean-Up -folder $workingDirectory
    }
    if($exportResult) {       
        $PDFfile = Add-VaultFile -From $localPDFfileLocation -To $vaultPDFfileLocation -FileClassification DesignVisualization -Hidden $hidePDF
        $file = Update-VaultFile -File $file._FullPath -AddAttachments @($PDFfile._FullPath) -Comment "3D-PDF file added"    
    }
}

if(-not $openResult) {
    throw("Failed to open document $($file.LocalPath)! Reason: $($openResult.ErrorMessage)")
}
if(-not $exportResult) {
    throw("Failed to export document $($file.LocalPath) to $localPDFfileLocation! Reason: $($Error[0])")
}
if(-not $closeResult) {
    throw("Failed to close document $($file.LocalPath)! Reason: $($closeResult.ErrorMessage))")
}
Write-Host "Completed job 'Create PDF as attachment'"