﻿
function Get-3DPdfTemplate {
    param(
        [string]$FileExt,
        $TemplateDirectory = (Join-Path -Path $env:POWERJOBS_MODULESDIR -ChildPath '3DPDF')
    )
    switch($FileExt) {
        ".iam" { $templateFullPath = Join-Path $TemplateDirectory "3DPdfTemplate.iam.pdf" ; break }
        ".ipt" { $templateFullPath = Join-Path $TemplateDirectory "3DPdfTemplate.ipt.pdf" ; break }
        default { $templateFullPath = Join-Path $TemplateDirectory "3DPdfTemplate.pdf" }
    }
    Write-Host "Using 3d-PDF template file: '$templateFullPath'"
    return $templateFullPath
}

Function Export-3DPdf {
    param(
    [Parameter(Mandatory = $true)]$Application,
    [Parameter(Mandatory = $true)]$Document,
    [Parameter(Mandatory = $true)][string]$PdfFullPath,
    [Inventor.AccuracyEnum]$Accuracy = "kHigh"
    )
    Write-Host "Activating 3D-PDF AddIn"
    $3DPdfAddin = $Application.ApplicationAddIns.ItemById("{3EE52B28-D6E0-4EA4-8AA6-C2A266DEBB88}")
    if(-not $3DPdfAddin) { 
        Write-Host "3D Pdf Addin not loaded! Exiting Job."; return; 
    }
    if($3DPdfAddin.Activated -ne $true){
        $3DPdfAddin.Activate()
        Write-Host "3D-PDF AddIn activated"
    }else{
        Write-host "3D-PDF AddIn was already activated"
    }

    [string[]]$DesignViewNames = $Document.ComponentDefinition.RepresentationsManager.ActiveDesignViewRepresentation.Name
    Write-Host "Get template path"
    $templateFullPath = Get-3DPdfTemplate -FileExt ($Document.FullFileName.Substring($Document.FullFileName.LastIndexOf('.')))
    Write-Host "Template path is: $templateFullPath"

    Write-Host "Creating settings object"
    $options = $Application.TransientObjects.CreateNameValueMap()
    $options.Clear()
    $options.Insert("ExportTemplate",$templateFullPath)
    $options.Insert("FileOutputLocation", $PdfFullPath)
    $options.Insert("ExportAnnotations", "0")
    $options.Insert("ExportWokFeatures", "0")
    $options.Insert("GenerateAndAttachSTEPFile", $false)
    $options.Insert("LimitToEntitiesInDVRs", $true)
    $options.Insert("ExportAllProperties", $true)
    $options.Insert("VisualizationQuality", $Accuracy)
    $options.Insert("ExportDesignViewRepresentations", $DesignViewNames)
    Write-Host "Finished creating settings object"

    $3DPdfConverter = $3DPdfAddin.Automation
    Write-Host "Publishing 3D-PDF..."
    $3DPdfConverter.Publish($Document, $options)
    Write-Host "Finished publishing 3D-PDF"
    Start-Sleep -Seconds 2
    if(Test-Path $PdfFullPath) {
        return $true
    } else {
        return $false
    }
}